/* $Workfile: OtxBrdD.h $   $Revision: 28 $    $Modtime: 6/21/01 2:22p $  */
#ifndef OTX_BRD_DEF_H
#define OTX_BRD_DEF_H
/******************************************************************************

  @doc PublicHwApi OtxBrdD

  Copyright (C) 1998-2001 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxBrdD | Constants, Macros, and Types for the Board Level Functions

  @contents2
  OtxBrdD.h |

  @index enum struct type | OtxBrdD

  @contents2
  OTX Board Level Constants, Macros, and Types |

  @head3 OtxBrdXXX Macro, Constant, and Type Reference |

  @index enum struct type | OtxBrdD

******************************************************************************/

#ifdef __cplusplus
extern "C" {
#endif

#include "OtxErr.h"
#include "OtxType.h"

// @enum Board Device Attributes
enum OtxBoardDeviceAttributesE {
  OTX_ATTR_BRD_SERIAL_NUMBER            = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_SZ) Read only. Serial Number of the board (ALL boards)
  OTX_ATTR_BRD_BUILD                    = OTX_ATTR_END + 1,  // @emem (OTX_ATTRIB_SZ) Read only. Board population build (ALL boards)
  OTX_ATTR_BRD_CIS_REV                  = OTX_ATTR_END + 2,  // @emem (OTX_ATTRIB_SZ) Read only. CIS Revision Number (PCMCIA boards)
  OTX_ATTR_BRD_CPLD_BUILD               = OTX_ATTR_END + 3,  // @emem (OTX_ATTRIB_SZ) Read only. FUTURE USE: CPLD Build (PCI boards)
  OTX_ATTR_BRD_BUS_ADDRESS              = OTX_ATTR_END + 4,  // @emem (OTX_ATTRIB_UINT32) Read only. WDM driver only. Bus specific location address for the board
  OTX_ATTR_BRD_PCMCIA_SOCKET_NUMBER     = OTX_ATTR_END + 5,  // @emem (OTX_ATTRIB_UINT32) Read only. PCMCIA Socket number (0,1). (PCMCIA boards)
  OTX_ATTR_BRD_PCI_DEVICE_NUMBER        = OTX_ATTR_END + 6,  // @emem (OTX_ATTRIB_UINT32) Read only. Device number of the PCI board (PCI boards)
  OTX_ATTR_BRD_PCI_FUNCTION_NUMBER      = OTX_ATTR_END + 7,  // @emem (OTX_ATTRIB_UINT32) Read only. Function number of the PCI board (PCI boards)
  OTX_ATTR_BRD_USER_STRING              = OTX_ATTR_END + 8,  // @emem (OTX_ATTRIB_SZ) Read only. User supplied string stored persistently on the board
  OTX_ATTR_BRD_PCMCIA_DONGLE_TYPE       = OTX_ATTR_END + 9,  // @emem (OTX_ATTRIB_SZ) Read/Write. For PCMCIA boards. Product number (HMA) of attached dongle.
                                                             // The driver provides customized transmit pulse masks (E1/T1 span) for each dongle type.
                                                             // <nl> Thor-2-PCMCIA board supports the following dongles:
                                                             // <nl> HMA-1021-1-1.0-P1   (standard dongle, preliminary version)
                                                             // <nl> HMA-1021-1-1.0      (standard dongle, released version)
                                                             // <nl> HMA-1074-1-1.0-P1   (monitor dongle,  preliminary version)
                                                             // <nl> Thor-2-PCMCIA-Plus board supports the following dongles:
                                                             // <nl> HMA-1076-2-1.0-P1   (Generator dongle, for battery powered equipment, preliminary version)
                                                             // <nl> HMA-1079-2-1.0-P1   (Monitor dongle, for battery powered equipment, preliminary version)
  OTX_ATTR_BRD_DPC_MAX_TIMESLICE        = OTX_ATTR_END + 10, // @emem (OTX_ATTRIB_UINT32) Read/Write. Maximum allowed time (in milliseconds) 
                                                             // to spend serving device interrupts. If this time is execeeded the devices generating 
                                                             // interrupts at an abnormal rate will be disabled (to prevent system from hanging)
  OTX_ATTR_BRD_PNP_ID                   = OTX_ATTR_END + 11, // @emem (OTX_ATTRIB_OCTETS) Read only. Wide-character string. 
                                                             // Plug-and-Play Id of this board. 
                                                             // Only applicable for the WDM driver.
  OTX_ATTR_BRD_END                      = OTX_ATTR_END + 12
};

typedef enum OtxBoardDeviceAttributesE OtxBoardDeviceAttributesE;


/*******************************************************************************
  @enum
    Board Result Codes
*******************************************************************************/
enum OtxBrdResultCodesE {
  OTX_BRD_RES_END                      = OTX_RES_END + 0
};

typedef enum OtxBrdResultCodesE OtxBrdResultCodesE;



/*---------------------------------------------------------------------------*\
  @enum
    Board Event Codes
\*---------------------------------------------------------------------------*/
enum OtxBrdEventCodesE {
  OTX_BRD_EC_AUTO_DISABLED        = 0x00, // @emem Fatal error has occurred. The board is automatically disabled.
  OTX_BRD_EC_INTR_FREQ_TOO_HIGH   = 0x01, // @emem Interrupt frequency is too high. Data loss is imminent.
  OTX_BRD_EC_INVALID_INTERRUPT    = 0x02, // @emem Invalid interrupt has occurred. Interrupt ignored.

  OTX_BRD_END_OF_EVENT_CODES
};

typedef enum OtxBrdEventCodesE OtxBrdEventCodesE;


/*---------------------------------------------------------------------------*\
  @enum 
    TSS Attributes
\*---------------------------------------------------------------------------*/
enum OtxTssDeviceAttributesE {
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_A  = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d0-d3. Valid values are 2048 (default), 4098, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_B  = OTX_ATTR_END + 1,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d4-d7. Valid values are 2048 (default), 4098, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_C  = OTX_ATTR_END + 2,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d8-d11. Valid values are 2048 (default), 4098, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_D  = OTX_ATTR_END + 3,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d12-d15. Valid values are 2048 (default), 4098, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_E  = OTX_ATTR_END + 4,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d16-d19. Valid values are 2048 (default), 4098, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_F  = OTX_ATTR_END + 5,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d20-d23. Valid values are 2048 (default), 4098, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_G  = OTX_ATTR_END + 6,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d24-d27. Valid values are 2048 (default), 4098, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_H  = OTX_ATTR_END + 7,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d28-d31. Valid values are 2048 (default), 4098, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.

  OTX_ATTR_TSS_END                       = OTX_ATTR_END + 8
};

typedef enum OtxTssDeviceAttributesE OtxTssDeviceAttributesE;



/*---------------------------------------------------------------------------*\
  @enum
    Time-Space Switch (TSS) Event Codes
\*---------------------------------------------------------------------------*/
enum OtxTssEventCodesE {
  OTX_TSS_EC_CLKERR_A             = 0x00, // @emem C8A or Frame A Clock failed
  OTX_TSS_EC_CLKERR_B             = 0x01, // @emem C8B or Frame B Clock failed
  OTX_TSS_EC_CLKERR_FR_COMP       = 0x02, // @emem FR_COMPn Clock failed
  OTX_TSS_EC_CLKERR_C16           = 0x03, // @emem C16+ C16- Clock failed
  OTX_TSS_EC_CLKERR_C4_C2         = 0x04, // @emem C4 or C2 Clock failed
  OTX_TSS_EC_CLKERR_SCLKX2        = 0x05, // @emem SCLKX2 Clock failed
  OTX_TSS_EC_CLKERR_SCLK          = 0x06, // @emem SCLK Clock failed
  OTX_TSS_EC_CLKERR_NETREF        = 0x07, // @emem NETREF Clock failed
  OTX_TSS_EC_SYSERR_NM_CAM_E      = 0x08, // @emem Even CAM Overflow Error (No Match)
  OTX_TSS_EC_SYSERR_NM_CAM_O      = 0x09, // @emem Odd CAM Overflow Error (No Match)
  OTX_TSS_EC_SYSERR_NM_CAM_L      = 0x0a, // @emem Local CAM Overflow Error (No Match)
  OTX_TSS_EC_SYSERR_CAM_E         = 0x0b, // @emem Even CAM Overflow Error
  OTX_TSS_EC_SYSERR_CAM_O         = 0x0c, // @emem Odd CAM Overflow Error
  OTX_TSS_EC_SYSERR_CAM_L         = 0x0d, // @emem Local CAM Overflow Error
  OTX_TSS_EC_SYSERR_HBUS          = 0x0e, // @emem H-BUS (CT Bus) Data Memory Access Error
  OTX_TSS_EC_SYSERR_FALLBACK      = 0x0f, // @emem Fallback Enable Indicator

  OTX_TSS_END_OF_EVENT_CODES
};

typedef enum OtxTssEventCodesE OtxTssEventCodesE;


// @enum Board Clock Source. The highways on the OTX boards are all synchronized to one
// clock. This type (used as parameter to <f OtxBrdSetClocks>) specified the source of
// this clock.
enum OtxBrdClockSourceE {
  OTX_CLOCK_SOURCE_INTERNAL        = 0x00,   // @emem Board Clock Source Internal Oscillator.
                                             // The board operates as a clock master. The clock
                                             // source is the internal oscillator populated on 
                                             // the OTX board. 
                                             // This mode can drive clocks on the H.100 bus (please 
                                             // refer to <t OtxBrdClockModeE>).

  OTX_CLOCK_SOURCE_CT_NETREF       = 0x01,   // @emem Board Clock Source CT_NETREF
                                             // The board operates as a clock slave, and slaves
                                             // to the CT_NETREF clock provided on the H.100 bus.

  OTX_CLOCK_SOURCE_A_CLOCKS        = 0x02,   // @emem Board Clock Source A Clocks (C8A & FRAMEA); 
                                             // MC-1 (inverted 4.096 MHz on C8A)
                                             // The board operates as a clock slave, and slaves
                                             // to the C8A & FRAMEA clocks provided on the H.100 bus.

  OTX_CLOCK_SOURCE_A_CLOCKS_ETCF   = 0x03,   // @emem Board Clock Source A Clocks (C8A & FRAMEA); 
                                             // ETCF (noninverted 8.192 MHz on C8A)
                                             // The board operates as a clock slave, and slaves
                                             // to the C8A & FRAMEA clocks provided on the H.100 bus.

  OTX_CLOCK_SOURCE_B_CLOCKS        = 0x04,   // @emem Board Clock Source B Clocks (C8B & FRAMEB); 
                                             // MC-1 (inverted 4.096 MHz on C8B)
                                             // The board operates as a clock slave, and slaves
                                             // to the C8B & FRAMEB clocks provided on the H.100 bus.

  OTX_CLOCK_SOURCE_B_CLOCKS_ETCF   = 0x05,   // @emem Board Clock Source B Clocks (C8B & FRAMEB); 
                                             // ETCF (noninverted 8.192 MHz on C8B)
                                             // The board operates as a clock slave, and slaves
                                             // to the C8B & FRAMEB clocks provided on the H.100 bus.

  OTX_CLOCK_SOURCE_MVIP            = 0x06,   // @emem Board Clock Source MVIP
                                             // The board operates as a clock slave, and slaves
                                             // to the /C4 clock provided on the H.100 bus.

  OTX_CLOCK_SOURCE_HMVIP           = 0x07,   // @emem Board Clock Source H-MVIP
                                             // The board operates as a clock slave, and slaves
                                             // to the /C16 clock provided on the H.100 bus.

  OTX_CLOCK_SOURCE_SC_BUS_2_MHZ    = 0x08,   // @emem Board Clock Source SC-Bus 2 Mhz
                                             // The board operates as a clock slave, and slaves
                                             // to the SCLKX2# clock provided on the H.100 bus.

  OTX_CLOCK_SOURCE_SC_BUS_4_8_MHZ  = 0x09,   // @emem Board Clock Source SC-Bus 4 or 8 Mhz
                                             // The board operates as a clock slave, and slaves
                                             // to the SCLK clock provided on the H.100 bus.

  OTX_CLOCK_SOURCE_LOCAL_0         = 0x0A,   // @emem Board Clock Source Local Reference 0. 
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 0.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_1         = 0x0B,   // @emem Board Clock Source Local Reference 1.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 1.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_2         = 0x0C,   // @emem Board Clock Source Local Reference 2.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 2.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_3         = 0x0D,   // @emem Board Clock Source Local Reference 3.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 3.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_4         = 0x0E,   // @emem Board Clock Source Local Reference 4.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 4.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_5         = 0x0F,   // @emem Board Clock Source Local Reference 5.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 5.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_6         = 0x10,   // @emem Board Clock Source Local Reference 6.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 6.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_7         = 0x11    // @emem Board Clock Source Local Reference 7.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 7.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

};

typedef enum OtxBrdClockSourceE OtxBrdClockSourceE;

// @enum Board Clock Mode. Specifies a connection/disconnection to a H.100 bus, clocks to drive, etc.
enum OtxBrdClockModeE {
  OTX_CLOCK_MODE_NA                = 0,      // @emem Board Clock Mode Not Applicable (used on an OTX boards 
                                             // which are not equipped with an H.100 interface, e.g. Thor-2-PCMCIA)

  OTX_CLOCK_MODE_LOCAL             = 1,      // @emem Board is disconnected (tri-stated) from the H.100 bus

  OTX_CLOCK_MODE_H100              = 2,      // @emem Board is connected to the H.100 bus (MC-1 mode). 
                                             // If this mode is used with any of the bus 
                                             // driving clock sources (see <t OtxBrdClockSourceE>), this mode 
                                             // will drive the C8A, C8B, FRAMEA and FRAMEB H.100 clocks in 
                                             // MC-1 mode (inverted 4.096 MHz).

  OTX_CLOCK_MODE_H100_ETCF         = 3       // @emem Board is connected to the H.100 bus (ETCF mode). 
                                             // If this mode is used with any of the bus 
                                             // driving clock sources (see <t OtxBrdClockSourceE>), this mode 
                                             // will drive the C8A, C8B, FRAMEA and FRAMEB H.100 clocks in 
                                             // ETCF mode (noninverted 8.192 MHz).
};

typedef enum OtxBrdClockModeE OtxBrdClockModeE;


#ifdef __cplusplus
}  // extern "C"
#endif

/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998-2001

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/
#endif    // OTX_BRD_DEF_H
