/* $Workfile: OtxJtag.h $   $Revision: 23 $    $Modtime: 7/17/00 5:00p $  */
#ifndef OTX_JTAG_H
#define OTX_JTAG_H
/*******************************************************************************

  @doc PublicHwApi OtxJtag

  Copyright (C) 2001 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxJtag | Prototypes for the JTAG Functions

  @contents2
  OtxJtag.h |

  @index func | OtxJtag

  @contents2
  OTX JTAG - OtxJtagXXX() | The API functions for the JTAG TBC device

  @head3 OtxJtagXXX() Function Reference |

  @index func | OtxJtag

*******************************************************************************/

#ifdef __cplusplus
  extern "C" {
#endif

#include "OtxType.h"
#include "OtxDef.h"

#include "OtxJtagD.h"

/*******************************************************************************

  @func
    Control function for the JTAG TBC device. 

  @xref
    <t OtxJtagControlCmdE> 

*******************************************************************************/
OTX_RESULT OtxJtagControl(
  IN  OTX_HANDLE hDevice,              // @parm Handle to the TBC Device
  IN  OtxJtagControlCmdE nCmd          // @parm Command to be executed
);


/*******************************************************************************

  @func
    Scan in the Instruction Register

  @xref
    <f OtxJtagScanDr>

*******************************************************************************/
OTX_RESULT OtxJtagScanIr(
  IN  OTX_HANDLE hDevice,           // @parm Handle to the TBC Device
  IN  OTX_INT32  nTms,              // @parm TMS chain number (0-7)
  IN  char *pszCommand,             // @parm Instruction string of be scanned in
  OUT  char *pszOutBuf              // @parm Instruction string scanned out
);

/*******************************************************************************

  @func
    Scan in the Data Register

  @xref
    <f OtxJtagScanIr>

*******************************************************************************/
OTX_RESULT OtxJtagScanDr(
  IN  OTX_HANDLE hDevice,           // @parm Handle to the TBC Device
  IN  OTX_INT32  nTms,              // @parm TMS chain number (0-7)
  IN  char *pszDataIn,              // @parm Data string to be scanned in
  OUT  char *pszDataOut             // @parm Data string scanned out
);


#ifdef __cplusplus
  } // extern "C"
#endif


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2001

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif // OTX_JTAG_H
