/* $Workfile: OtxPotsD.h $   $Revision: 14 $    $Modtime: 1/23/01 5:27p $  */
#ifndef OTX_POTS_DEF_H
#define OTX_POTS_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxPotsD

  Copyright (C) 1998, 1999 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxPotsD | Constants, Macros, and Types for the Analog Phone Functions

  @contents2
  OtxPotsD.h |

  @index enum struct type | OtxPotsD

  @contents2
  OTX POTS Line Interface Device Constants, Macros, and Types |

  @head3 OtxPotsXXX Macro, Constant, and Type Reference |

  @index enum struct type | OtxPotsD

*******************************************************************************/

#ifdef __cplusplus
extern "C" {
#endif

/*******************************************************************************
  @enum
    POTS Notify Causes. Note: Inband signals (e.g. DTMF digits) must
    be detected by a DSP module
*******************************************************************************/
enum OtxPotsEventCodeE {
  OTX_POTS_WAKE_UP                =  1,  // @emem Ring signal detected waking-up the line interface device, which had
                                         //       been in power-down mode.
  OTX_POTS_RING_SIGNAL_DETECTED   =  2,  // @emem A ring signal has been detected on tip and ring
  OTX_POTS_RING_SIGNAL_ON         =  3,  // @emem Ring signal On-State detected (Off --> On transition)
  OTX_POTS_RING_SIGNAL_OFF        =  4,  // @emem Ring signal Off-state detected (On --> Off transition)
  OTX_POTS_INVALID_RING_SIGNAL    =  5,  // @emem An invalid ring signal detected
  OTX_POTS_CALLER_ID              =  6,  // @emem Caller-ID (FSK octets) have been received
};

typedef enum OtxPotsEventCodeE OtxPotsEventCodeE;



/*******************************************************************************
  @enum
    Operating modes of the POTS Line Interface (Li) Devices.
  @devnote
    The values are meaningful
  @xref
    <f OtxPotsSetLiMode>
    <f OtxPotsGetLiMode>
*******************************************************************************/
enum OtxPotsLiModeE {
  OTX_POTS_MODE_SLEEP         = 0x0000,  // @emem The line interface device is sleeping
  OTX_POTS_MODE_RINGING       = 0x4000,  // @emem The line interface device is ringing
  OTX_POTS_MODE_CONVERSATION  = 0x8000,  // @emem The line interface device is in conversation mode
  OTX_POTS_MODE_PULSE_DIALING = 0xC000   // @emem The line interface device is pulse dialing
};

typedef enum OtxPotsLiModeE OtxPotsLiModeE;

// @enum POTS Device Attributes
enum OtxPotsDeviceAttributesE {
  OTX_ATTR_POTS_CID_ENABLED = OTX_ATTR_END + 0, // @emem (OTX_ATTRIB_BOOL) Read/Write. For OTX_DEVICE_LI_POTS devices. Caller ID detection enabled/disabled
  OTX_ATTR_POTS_CFG_SET     = OTX_ATTR_END + 1, // @emem (OTX_ATTRIB_UINT32) Read/Write. For OTX_DEVICE_LI_CONTROLLER devices. Set the Country Specific configuration set
                                                // for the POTS line interface (e.g. DC characteristics, ringer impedance, filter coefficients, etc).
                                                // Please see <t OtxPotsCfgSetE> for supported configuration sets.
  OTX_ATTR_POTS_END         = OTX_ATTR_END + 2
};

typedef enum OtxPotsDeviceAttributesE OtxPotsDeviceAttributesE;

// @enum POTS Country Specific configuration sets (to be used with the <e OtxPotsDeviceAttributesE.OTX_ATTR_POTS_CFG_SET> attribute
enum OtxPotsCfgSetE {
  OTX_POTS_CFG_SET_USA       = 0,  // @emem POTS configuration for USA
  OTX_POTS_CFG_SET_GERMANY   = 1,  // @emem POTS configuration for Germany
  OTX_POTS_CFG_SET_UK        = 2,  // @emem POTS configuration for United Kingdom
  OTX_POTS_CFG_SET_FRANCE    = 3,  // @emem POTS configuration for France
  OTX_POTS_CFG_SET_AUSTRALIA = 4,  // @emem POTS configuration for Australia
  OTX_POTS_CFG_SET_JAPAN     = 5,  // @emem POTS configuration for Japan
};
typedef enum OtxPotsCfgSetE OtxPotsCfgSetE;



// @type POTS_HANDLE | An opaque object reference for definitions kept internal to the module.
typedef void *POTS_HANDLE;


#ifdef __cplusplus
}  // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998, 1999

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif    // OTX_POTS_DEF_H
